@@ -53,13 +53,12 @@
 #' #Just 'beta' parameters
 #' MCMCsummary(MCMC_data, params = 'beta')
 #'
-#' #Just 'beta[1]', 'gamma[4]', and 'alpha[3]'
+#' #Just 'beta[1]', 'beta[4]', and 'alpha[3]'
 #' #'params' takes regular expressions when ISB = FALSE, square brackets must be escaped with '\\'
-#' MCMCsummary(MCMC_data, params = c('beta\\[1\\]', 'gamma\\[4\\]', 'alpha\\[3\\]'), ISB = FALSE)
+#' MCMCsummary(MCMC_data, params = c('beta\\[1\\]', 'beta\\[4\\]', 'alpha\\[3\\]'), ISB = FALSE)
 #'
 #' @export
 
-
 MCMCsummary <- function(object,
                       params = 'all',
                       excl = NULL,
@@ -71,11 +70,6 @@ MCMCsummary <- function(object,
                       func_name = NULL)
 {
   #SORTING BLOCK
-  if(class(object) == 'jagsUI')
-  {
-    object <- object$samples
-  }
-
   if(typeof(object) == 'double')
   {
     object2 <- MCMCchains(object, params, excl, ISB, mcmc.list = FALSE)
